@@ -9,16 +9,20 @@ class RokuBox1: public PIRKeysetMetaData
 {
 public:
   RokuBox1(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 class RokuBox2: public PIRKeysetMetaData
 {
 public:
   RokuBox2(
-    QObject *guiObject,
     unsigned int index);
+
+  virtual void populateProtocol(
+    QObject *guiObject);
 };
 
 #endif // ROKU_H
